@@ -35,6 +35,12 @@ def _display_docker_images(docker_images_list):
 
     Returns:
     """
-    docker_images_table = [[docker_img.id, docker_img.name, docker_img.repository_type, docker_img.path,
-                            docker_img.entry_point] for docker_img in docker_images_list]
-    info_message(list_to_table(docker_images_table, headers=["ID", "Name", "Repository Type", "Path", "Entry Point"]))
+    docker_images_table = [[docker_img.id,
+                            docker_img.name,
+                            "V" if docker_img.is_default else "",
+                            docker_img.repository_type,
+                            docker_img.path,
+                            docker_img.entry_point]
+                           for docker_img in docker_images_list]
+    info_message(list_to_table(docker_images_table, headers=["ID", "Name", "Default", "Repository Type", "Path",
+                                                             "Entry Point"]))
