@@ -21,11 +21,10 @@ class DockerImage(BaseController):
 
         res = cls.query('getDockerImagesByOwnerId', limit=limit,
                         ownerId=cls.get_current_user(), next=next_)
-
         if res is None:
             return []
 
-        docker_images = [DockerImageDetails(docker_image) for docker_image in res['getDockerImagesByOwnerId']
-                         if docker_image['isActive']]
+        docker_images = [DockerImageDetails(docker, res['fetchProfile']['defaultDockerImageId'] == docker['id'])
+                         for docker in res['fetchProfile']['dockers'] if docker['isActive']]
 
         return docker_images
