@@ -276,3 +276,31 @@ class TestJobs(BaseTest):
         status = job.get_status()
         assert str(status) == 'JobStatus.failed'
 
+    @BaseTest.with_config_and_env(authenticated=True)
+    @mock.patch('disco.job.Job._download_task_results')
+    def test_job_get_results_no_block(self, mock_download_task_results):
+        fake_task_results = self.random_list('task_result')
+
+        mock_download_task_results.return_value = fake_task_results
+
+        job = disco.Job('job_id')
+        task_results = job.get_results()
+
+        assert task_results == fake_task_results
+
+    @BaseTest.with_config_and_env(authenticated=True)
+    @mock.patch('disco.job.Job.wait_for_finish')
+    @mock.patch('disco.job.Job._download_task_results')
+    def test_job_get_results_with_block(self, mock_download_task_results, mock_wait_for_finish):
+        fake_task_results = self.random_list('task_result')
+
+        mock_download_task_results.return_value = fake_task_results
+        mock_wait_for_finish.return_value = True
+
+        job = disco.Job('job_id')
+        task_results = job.get_results(block=True)
+
+        block_timeout = disco.Job.TIMEOUT
+        mock_wait_for_finish.assert_called_once_with(timeout=block_timeout)
+
+        assert task_results == fake_task_results
